@@ -21,17 +21,19 @@
 package gnu.gcjwebplugin;
 
 import java.awt.Dimension;
-import java.io.*;
-import java.util.Arrays;
-import java.util.StringTokenizer;
+import java.io.File;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.io.IOException;
+import java.io.StreamTokenizer;
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
-import java.net.MalformedURLException;
 import java.util.ArrayList;
-import java.util.Map;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.StringTokenizer;
 
 class AppletTag
 {
